========
AMP Tags
========

Django template tags designed to make it easier to build `Google Amp <http://ampproject.com>`_ websites.

Quick Start
-----------

1. Add 'amptags' to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'amptags',
    ]


